@@ -1,6 +1,6 @@
 /*
  *  Phusion Passenger - https://www.phusionpassenger.com/
- *  Copyright (c) 2011-2015 Phusion Holding B.V.
+ *  Copyright (c) 2011-2017 Phusion Holding B.V.
  *
  *  "Passenger", "Phusion Passenger" and "Union Station" are registered
  *  trademarks of Phusion Holding B.V.
@@ -483,6 +483,9 @@ public:
 	void forceMaxConcurrency(int value) {
 		assert(value >= 0);
 		concurrency = value;
+		for (unsigned i = 0; i < sessionSocketCount; i++) {
+			sessionSockets[i]->concurrency = concurrency;
+		}
 	}
 
 	void shutdownNotRequired() {
