@@ -1,6 +1,6 @@
 /*
  *  Phusion Passenger - https://www.phusionpassenger.com/
- *  Copyright (c) 2010-2015 Phusion Holding B.V.
+ *  Copyright (c) 2010-2017 Phusion Holding B.V.
  *
  *  "Passenger", "Phusion Passenger" and "Union Station" are registered
  *  trademarks of Phusion Holding B.V.
@@ -58,7 +58,7 @@
 #include <Utils.h>
 #include <Utils/IOUtils.h>
 #include <Utils/StrIntUtils.h>
-#include <Utils/Timer.h>
+#include <Utils/SystemTime.h>
 #include <Utils/HttpConstants.h>
 #include <Utils/ReleaseableScopedPointer.h>
 #include <Logging.h>
@@ -314,19 +314,6 @@ private:
 		return conn;
 	}
 
-	vector<string> getConfigFiles(server_rec *s) const {
-		server_rec *server;
-		vector<string> result;
-
-		for (server = s; server != NULL; server = server->next) {
-			if (server->defn_name != NULL) {
-				result.push_back(server->defn_name);
-			}
-		}
-
-		return result;
-	}
-
 	bool hasModRewrite() {
 		if (m_hasModRewrite == UNKNOWN) {
 			if (ap_find_linked_module("mod_rewrite.c")) {
@@ -580,8 +567,8 @@ private:
 				return httpStatus;
 			}
 
-			this_thread::disable_interruption di;
-			this_thread::disable_syscall_interruption dsi;
+			boost::this_thread::disable_interruption di;
+			boost::this_thread::disable_syscall_interruption dsi;
 			bool expectingBody;
 
 			expectingBody = ap_should_client_block(r);
@@ -630,7 +617,6 @@ private:
 			 * util_script.c's source. :-(
 			 */
 			char backendData[MAX_STRING_LEN];
-			Timer timer;
 			getsfunc_BRIGADE(backendData, MAX_STRING_LEN, bb);
 
 			// The bucket brigade is an interface to the HTTP response sent by the
@@ -1251,7 +1237,8 @@ public:
 	    : cstat(1024),
 	      watchdogLauncher(IM_APACHE)
 	{
-		serverConfig.finalize();
+		passenger_postprocess_config(s);
+
 		Passenger::setLogLevel(serverConfig.logLevel);
 		if (serverConfig.logFile != NULL) {
 			int errcode;
@@ -1287,17 +1274,27 @@ public:
 			const char *webServerDesc = ap_get_server_version();
 		#endif
 
+		ap_version_t version;
+		ap_get_server_revision(&version);
+		string webServerVersion = toString(version.major) + "." + toString(version.minor) + "." + toString(version.patch);
+		if (version.add_string != NULL) {
+			webServerVersion.append(version.add_string);
+		}
+
 		VariantMap params;
 		params
 			.setPid ("web_server_control_process_pid", getpid())
-			.setStrSet("web_server_config_files", getConfigFiles(s))
 			.set    ("server_software", webServerDesc)
+			.set    ("server_version", webServerVersion)
 			.setBool("multi_app", true)
 			.setBool("load_shell_envvars", true)
 			.set    ("file_descriptor_log_file", (serverConfig.fileDescriptorLogFile == NULL)
 				? "" : serverConfig.fileDescriptorLogFile)
+			.setInt	("socket_backlog", serverConfig.socketBacklog)
 			.set    ("data_buffer_dir", serverConfig.dataBufferDir)
 			.set    ("instance_registry_dir", serverConfig.instanceRegistryDir)
+			.setBool("disable_security_update_check", serverConfig.disableSecurityUpdateCheck)
+			.set    ("security_update_check_proxy", serverConfig.securityUpdateCheckProxy)
 			.setBool("user_switching", serverConfig.userSwitching)
 			.set    ("default_user", serverConfig.defaultUser)
 			.set    ("default_group", serverConfig.defaultGroup)
@@ -1308,6 +1305,7 @@ public:
 			.setInt ("stat_throttle_rate", serverConfig.statThrottleRate)
 			.set    ("analytics_log_user", serverConfig.analyticsLogUser)
 			.set    ("analytics_log_group", serverConfig.analyticsLogGroup)
+			.setBool("union_station_support", serverConfig.unionStationSupport)
 			.set    ("union_station_gateway_address", serverConfig.unionStationGatewayAddress)
 			.setInt ("union_station_gateway_port", serverConfig.unionStationGatewayPort)
 			.set    ("union_station_gateway_cert", serverConfig.unionStationGatewayCert)
@@ -1562,8 +1560,8 @@ static Hooks *hooks = NULL;
 static apr_status_t
 destroy_hooks(void *arg) {
 	try {
-		this_thread::disable_interruption di;
-		this_thread::disable_syscall_interruption dsi;
+		boost::this_thread::disable_interruption di;
+		boost::this_thread::disable_syscall_interruption dsi;
 		P_DEBUG("Shutting down Phusion Passenger...");
 		delete hooks;
 		hooks = NULL;
@@ -1598,6 +1596,7 @@ init_module(apr_pool_t *pconf, apr_pool_t *plog, apr_pool_t *ptemp, server_rec *
 	 */
 	if (hooks == NULL) {
 		oxt::initialize();
+		SystemTime::initialize();
 	} else {
 		P_DEBUG("Restarting Phusion Passenger....");
 		delete hooks;
@@ -1733,4 +1732,3 @@ passenger_register_hooks(apr_pool_t *p) {
 /**
  * @}
  */
-
